@@ -5,12 +5,11 @@ use warnings;
 
 use parent qw(
     Net::WebSocket::Frame
+    Net::WebSocket::Base::Typed
 );
 
-use Net::WebSocket::X ();
-
 use constant get_fin => 1;
-use constant is_control => 1;
+use constant is_control_frame => 1;
 
 sub _assemble_length {
     my ($class, $payload_sr) = @_;
@@ -18,7 +17,7 @@ sub _assemble_length {
     if (length $$payload_sr > 125) {
         my $type = $class->get_type();
 
-        die Net::WebSocket::X->create('ControlPayloadTooLong', $type, $$payload_sr);
+        die "A “$type” frame cannot have a payload of over 125 bytes!";
     }
 
     return( chr(length $$payload_sr), q<> );
